package VMOMI::HostDigestInfoDigestMethodType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
